<?php

namespace Litecms\Sponserbonus\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Sponserbonus\Http\Requests\SponserbonusRequest;
use Litecms\Sponserbonus\Interfaces\SponserbonusRepositoryInterface;
use Litecms\Sponserbonus\Models\Sponserbonus;

/**
 * Resource controller class for sponserbonus.
 */
class SponserbonusResourceController extends BaseController
{

    /**
     * Initialize sponserbonus resource controller.
     *
     * @param type SponserbonusRepositoryInterface $sponserbonus
     *
     * @return null
     */
    public function __construct(SponserbonusRepositoryInterface $sponserbonus)
    {
        parent::__construct();
        $this->repository = $sponserbonus;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Sponserbonus\Repositories\Criteria\SponserbonusResourceCriteria::class);
    }

    /**
     * Display a list of sponserbonus.
     *
     * @return Response
     */
    public function index(SponserbonusRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Sponserbonus\Repositories\Presenter\SponserbonusPresenter::class)
                ->$function();
        }

        $sponserbonuses = $this->repository->paginate();

        return $this->response->title(trans('sponserbonus::sponserbonus.names'))
            ->view('sponserbonus::sponserbonus.index', true)
            ->data(compact('sponserbonuses'))
            ->output();
    }

    /**
     * Display sponserbonus.
     *
     * @param Request $request
     * @param Model   $sponserbonus
     *
     * @return Response
     */
    public function show(SponserbonusRequest $request, Sponserbonus $sponserbonus)
    {

        if ($sponserbonus->exists) {
            $view = 'sponserbonus::sponserbonus.show';
        } else {
            $view = 'sponserbonus::sponserbonus.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('sponserbonus::sponserbonus.name'))
            ->data(compact('sponserbonus'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new sponserbonus.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(SponserbonusRequest $request)
    {

        $sponserbonus = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('sponserbonus::sponserbonus.name')) 
            ->view('sponserbonus::sponserbonus.create', true) 
            ->data(compact('sponserbonus'))
            ->output();
    }

    /**
     * Create new sponserbonus.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SponserbonusRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $sponserbonus                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('sponserbonus::sponserbonus.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('sponserbonus/sponserbonus/' . $sponserbonus->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/sponserbonus/sponserbonus'))
                ->redirect();
        }

    }

    /**
     * Show sponserbonus for editing.
     *
     * @param Request $request
     * @param Model   $sponserbonus
     *
     * @return Response
     */
    public function edit(SponserbonusRequest $request, Sponserbonus $sponserbonus)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('sponserbonus::sponserbonus.name'))
            ->view('sponserbonus::sponserbonus.edit', true)
            ->data(compact('sponserbonus'))
            ->output();
    }

    /**
     * Update the sponserbonus.
     *
     * @param Request $request
     * @param Model   $sponserbonus
     *
     * @return Response
     */
    public function update(SponserbonusRequest $request, Sponserbonus $sponserbonus)
    {
        try {
            $attributes = $request->all();

            $sponserbonus->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('sponserbonus::sponserbonus.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('sponserbonus/sponserbonus/' . $sponserbonus->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('sponserbonus/sponserbonus/' . $sponserbonus->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the sponserbonus.
     *
     * @param Model   $sponserbonus
     *
     * @return Response
     */
    public function destroy(SponserbonusRequest $request, Sponserbonus $sponserbonus)
    {
        try {

            $sponserbonus->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('sponserbonus::sponserbonus.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('sponserbonus/sponserbonus/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('sponserbonus/sponserbonus/' . $sponserbonus->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple sponserbonus.
     *
     * @param Model   $sponserbonus
     *
     * @return Response
     */
    public function delete(SponserbonusRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('sponserbonus::sponserbonus.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('sponserbonus/sponserbonus'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/sponserbonus/sponserbonus'))
                ->redirect();
        }

    }

    /**
     * Restore deleted sponserbonuses.
     *
     * @param Model   $sponserbonus
     *
     * @return Response
     */
    public function restore(SponserbonusRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('sponserbonus::sponserbonus.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/sponserbonus/sponserbonus'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/sponserbonus/sponserbonus/'))
                ->redirect();
        }

    }

}
