<?php

namespace Litecms\Sponserbonus\Providers;

use Illuminate\Support\ServiceProvider;

class SponserbonusServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'sponserbonus');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'sponserbonus');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.sponserbonus', function ($app) {
            return $this->app->make('Litecms\Sponserbonus\Sponserbonus');
        });

                // Bind Sponserbonus to repository
        $this->app->bind(
            'Litecms\Sponserbonus\Interfaces\SponserbonusRepositoryInterface',
            \Litecms\Sponserbonus\Repositories\Eloquent\SponserbonusRepository::class
        );

        $this->app->register(\Litecms\Sponserbonus\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Sponserbonus\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.sponserbonus'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/sponserbonus.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/sponserbonus')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/sponserbonus')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
